#! /usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _npmRun = require('npm-run');

var _npmRun2 = _interopRequireDefault(_npmRun);

var _winston = require('winston');

var _winston2 = _interopRequireDefault(_winston);

var _postUrlValidator = require('./post-url-validator');

var _postUrlValidator2 = _interopRequireDefault(_postUrlValidator);

var _imageProcessor = require('./image-processor');

var _imageProcessor2 = _interopRequireDefault(_imageProcessor);

var _linkChecker = require('./link-checker');

var _linkChecker2 = _interopRequireDefault(_linkChecker);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var postsGlob = _path2.default.join(process.cwd(), '**/_posts/*.+(md|markdown)');
var _siteFolder = _path2.default.join(process.cwd(), '/_site');

process.on('unhandledRejection', function (reason) {
  throw reason;
});

_winston2.default.info('ritter-jekyll ' + require('../package.json').version);

_winston2.default.info('Validating post urls...');
new _postUrlValidator2.default().validate(postsGlob);
_winston2.default.info('urls are valid!');

_winston2.default.info('Running image processor...');
new _imageProcessor2.default().run(_siteFolder + '/images').then(function () {
  if (process.env.NODE_ENV !== 'production') {
    _winston2.default.info('Running markdown-proofing...');
    var configurationPath = _path2.default.resolve(__dirname, './markdown-proofing-configuration.json');
    var markdownProofing = _npmRun2.default.execSync('markdown-proofing -c "' + configurationPath + '" "' + postsGlob + '"');
    _winston2.default.info(markdownProofing.toString());

    _winston2.default.info('Running link checker...');
    new _linkChecker2.default().validate(postsGlob).then(function (linkCheckerRes) {
      _winston2.default.info(linkCheckerRes.length + ' ' + (linkCheckerRes.length === 1 ? 'link is' : 'links are') + ' valid!');
    }).catch(function (err) {
      if (Array.isArray(err)) {
        var errors = err.filter(function (e) {
          return e.broken;
        }).map(function (e) {
          return e.brokenReason + ': ' + e.url.original;
        });

        throw new Error(errors.length + ' broken link issue' + (errors.length === 1 ? '' : 's') + ':\n\n' + errors.join('\n') + '\n');
      } else {
        throw new Error(err);
      }
    });
  }
});