'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _brokenLinkChecker = require('broken-link-checker');

var _brokenLinkChecker2 = _interopRequireDefault(_brokenLinkChecker);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _globby = require('globby');

var _globby2 = _interopRequireDefault(_globby);

var _markdownLinkExtractor = require('markdown-link-extractor');

var _markdownLinkExtractor2 = _interopRequireDefault(_markdownLinkExtractor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var LinkChecker = function () {
  function LinkChecker() {
    var logger = arguments.length <= 0 || arguments[0] === undefined ? null : arguments[0];

    _classCallCheck(this, LinkChecker);

    this.logger = logger || require('winston');
  }

  _createClass(LinkChecker, [{
    key: 'validate',
    value: function validate(path) {
      var _this = this;

      var files = _globby2.default.sync(path);
      var links = [];

      // Get links from files
      files.forEach(function (file) {
        var _links;

        var text = _fs2.default.readFileSync(file, 'utf8');
        var textHttpLinks = (0, _markdownLinkExtractor2.default)(text).filter(function (x) {
          return (/^http/i.test(x)
          );
        });

        (_links = links).push.apply(_links, _toConsumableArray(textHttpLinks));
      });

      // Get distinct links, normalizing to lowercase
      links = Array.from(new Set(links.map(function (link) {
        return link.toLowerCase();
      })));

      if (links.length === 0) {
        return Promise.resolve();
      }

      var brokenLinkCheckerPromise = new Promise(function (resolve, reject) {
        var results = [];

        var enqueueErrorsCount = 0;

        var urlChecker = new _brokenLinkChecker2.default.UrlChecker({}, {
          link: function link(result) {
            results.push(result);

            if (results.length + enqueueErrorsCount === links.length) {
              var filteredResults = results.filter(function (x) {
                return x.brokenReason !== 'BLC_UNKNOWN';
              });

              if (filteredResults.some(function (x) {
                return x.broken;
              })) {
                reject(filteredResults);
              } else {
                resolve(filteredResults);
              }
            }
          }
        });

        links.forEach(function (link) {
          var enqueueResult = urlChecker.enqueue(link);

          if (enqueueResult instanceof Error) {
            enqueueErrorsCount++;
          }
        });
      });

      var nonSecureLinkCheckerPromise = new Promise(function (resolve) {
        var results = [];

        var nonSecureLinks = links.filter(function (link) {
          return (/^http:/i.test(link)
          );
        });

        if (nonSecureLinks.length === 0) {
          resolve();
        }

        var enqueueErrorsCount = 0;

        var urlChecker = new _brokenLinkChecker2.default.UrlChecker({}, {
          link: function link(result) {
            results.push(result);

            if (results.length + enqueueErrorsCount === nonSecureLinks.length) {
              results.filter(function (x) {
                return !x.broken;
              }).forEach(function (x) {
                var originalHttpLink = x.url.original.replace(/^https:/i, 'http:');

                _this.logger.warn('Consider using HTTPS for ' + originalHttpLink);
              });

              resolve(results);
            }
          }
        });

        nonSecureLinks.forEach(function (link) {
          var httpsLink = link.replace(/^http:/i, 'https:');
          var enqueueResult = urlChecker.enqueue(httpsLink);

          if (enqueueResult instanceof Error) {
            enqueueErrorsCount++;
          }
        });
      });

      return Promise.all([nonSecureLinkCheckerPromise, brokenLinkCheckerPromise]);
    }
  }]);

  return LinkChecker;
}();

exports.default = LinkChecker;